@@ -3,6 +3,7 @@ import datetime
 import inspect
 import json
 import logging
+import random
 import sys
 
 import tornado.web
@@ -14,9 +15,20 @@ from qiskit.qobj import QasmQobj as Qobj
 from qctic.backend import (QCticQasmSimulator, QCticStatevectorSimulator,
                            QCticUnitarySimulator)
 
+_MAX_WAIT_SECS = 10
+
 _logger = logging.getLogger(__name__)
 
 
+def _init_logging():
+    try:
+        import coloredlogs
+        coloredlogs.install(level=logging.DEBUG)
+    except ImportError:
+        logging.basicConfig()
+        logging.getLogger().setLevel(logging.DEBUG)
+
+
 def _inspect_execute_params(aer_backend):
     sig_execute = inspect.signature(execute)
     sig_backend_run = inspect.signature(aer_backend.run)
@@ -39,6 +51,45 @@ def _get_aer_backend(backend_name):
     return Aer.get_backend(simulators[backend_name])
 
 
+async def _run_job(job_store, job_id):
+    _logger.debug("Starting task for job: %s", job_id)
+    wait_secs = round(random.uniform(0, _MAX_WAIT_SECS), 1)
+    _logger.debug("Waiting %s s. for job: %s", wait_secs, job_id)
+    await asyncio.sleep(wait_secs)
+    _logger.info("Running job: %s", job_id)
+
+    job_data = job_store[job_id]
+
+    job_data.update({
+        "status": JobStatus.RUNNING.name,
+        "date_start": datetime.datetime.utcnow().isoformat()
+    })
+
+    qobj = Qobj.from_dict(job_data["qobj"])
+    circuits, run_config, user_qobj_header = disassemble(qobj)
+    aer_backend = _get_aer_backend(user_qobj_header.get("backend_name"))
+
+    execute_kwargs = {}
+    execute_kwargs.update(run_config)
+    execute_kwargs.update(job_data.get("run_params", {}))
+
+    execute_kwargs = {
+        key: val for key, val in execute_kwargs.items()
+        if key in _inspect_execute_params(aer_backend)
+    }
+
+    aer_job = execute(circuits, aer_backend, **execute_kwargs)
+    aer_job_result = aer_job.result()
+
+    _logger.info("Job finished: %s", job_id)
+
+    job_data.update({
+        "status": JobStatus.DONE.name,
+        "date_end": datetime.datetime.utcnow().isoformat(),
+        "result": aer_job_result.to_dict()
+    })
+
+
 class JobsHandler(tornado.web.RequestHandler):
     def initialize(self, job_store):
         self.job_store = job_store
@@ -49,37 +100,10 @@ class JobsHandler(tornado.web.RequestHandler):
 
     def post(self):
         job_data = json.loads(self.request.body)
-        qobj = Qobj.from_dict(job_data["qobj"])
-        circuits, run_config, user_qobj_header = disassemble(qobj)
-        aer_backend = _get_aer_backend(user_qobj_header.get("backend_name"))
-
-        execute_kwargs = {}
-        execute_kwargs.update(run_config)
-        execute_kwargs.update(job_data.get("run_params", {}))
-
-        execute_kwargs = {
-            key: val for key, val in execute_kwargs.items()
-            if key in _inspect_execute_params(aer_backend)
-        }
-
-        job_data.update({
-            "date_start": datetime.datetime.utcnow().isoformat()
-        })
-
-        _logger.info("Running job for circuit:\n%s", circuits[0])
-
-        aer_job = execute(circuits[0], aer_backend, **execute_kwargs)
-        aer_job_result = aer_job.result()
-
-        _logger.info("Job finished")
-
-        job_data.update({
-            "date_end": datetime.datetime.utcnow().isoformat(),
-            "status": JobStatus.DONE.name,
-            "result": aer_job_result.to_dict()
-        })
-
-        self.job_store[job_data["job_id"]] = job_data
+        job_id = job_data["job_id"]
+        job_data.update({"status": JobStatus.QUEUED.name})
+        self.job_store[job_id] = job_data
+        asyncio.ensure_future(_run_job(self.job_store, job_id))
 
 
 class JobHandler(tornado.web.RequestHandler):
@@ -109,10 +133,8 @@ def build_app():
 
 
 def run_local_server():
-    logging.basicConfig()
-    logging.getLogger().setLevel(logging.DEBUG)
-
     try:
+        _init_logging()
         port = int(sys.argv[1]) if len(sys.argv) > 1 else 9090
         app = build_app()
         app.listen(port)
