@@ -55,9 +55,18 @@ class GetJobsQuerySchema(Schema):
 class JobSchema(Schema):
     job_id = fields.Str(required=True)
 
-    date_submit = fields.DateTime(required=True, format="iso")
-    date_start = fields.DateTime(format="iso")
-    date_end = fields.DateTime(format="iso")
+    date_submit = fields.AwareDateTime(
+        required=True,
+        format="iso",
+        default_timezone=datetime.timezone.utc)
+
+    date_start = fields.AwareDateTime(
+        format="iso",
+        default_timezone=datetime.timezone.utc)
+
+    date_end = fields.AwareDateTime(
+        format="iso",
+        default_timezone=datetime.timezone.utc)
 
     qobj = fields.Mapping(
         required=True,
